﻿using System;
using System.Drawing;
using System.Net;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.WinForms;

namespace _9115
{
    public partial class Form1 : Form
    {
        private Timer _updateTimer;
        //private string LAYER_NAME = "radar_meteo_imagery_nexrad_time";

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            _updateTimer = new Timer();
            _updateTimer.Interval = 60000 * 4;
            _updateTimer.Tick += _updateTimer_Tick;
            updateImage();


            _updateTimer.Start();

            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;


            ArcGISServerRestLayer _arcGISLayer = new ArcGISServerRestLayer(new Uri(@"https://nowcoast.noaa.gov/arcgis/rest/services/nowcoast/sat_meteo_imagery_time/MapServer/export"));
            _arcGISLayer.SendingWebRequest += _arcGISLayer_SendingWebRequest;
            _arcGISLayer.Parameters.Add("transparent", "true");
            _arcGISLayer.Parameters.Add("layers", "show:3");
            _arcGISLayer.IsVisible = true;

            LayerOverlay layerOverlay = new LayerOverlay();

            layerOverlay.Layers.Add(_arcGISLayer);
            winformsMap1.Overlays.Add(layerOverlay);

            _arcGISLayer.Open();
            winformsMap1.CurrentExtent = new RectangleShape(-169.8, 60.5, -63.5, 15.4);

            winformsMap1.Refresh();
        }

        private void updateImage()
        {
            string radarURL = "https://nowcoast.noaa.gov/arcgis/rest/services/nowcoast/radar_meteo_imagery_nexrad_time/MapServer/export?bbox=-169.8,15.4.-63.5,60.5&bboxSR=&layers=show:3&layerDefs=&size=&imageSR=&format=png&transparent=false&dpi=400&time=&layerTimeOptions=&dynamicLayers=&gdbVersion=&mapScale=&f=image";

            HttpWebRequest request = HttpWebRequest.Create(radarURL) as HttpWebRequest;
            request.Accept = "image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, application/x-shockwave-flash, application/vnd.ms-excel, application/vnd.ms-powerpoint, application/msword, */*";
            request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)";
            HttpWebResponse response = request.GetResponse() as HttpWebResponse;

            if (request.HaveResponse)
            {
                if (response.StatusCode == HttpStatusCode.OK)
                {
                    Image anImage = Image.FromStream(response.GetResponseStream());
                    anImage.Save(@"radar.png");
                }
            }

            response.Close();
        }


        private void _updateTimer_Tick(object sender, EventArgs e)
        {
            _updateTimer.Stop();

            updateImage();

            _updateTimer.Start();
        }

        private void _arcGISLayer_SendingWebRequest(object sender, SendingWebRequestEventArgs e)
        {
            System.Diagnostics.Debug.WriteLine(e.WebRequest.RequestUri.ToString());
        }
    }
}
